"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var memory_storage_service_1 = require("./memory-storage.service");
var session_storage_service_1 = require("./session-storage.service");
var local_storage_service_1 = require("./local-storage.service");
var PreferencesService = (function () {
    function PreferencesService(memoryService, localService, sessionService) {
        this.memoryService = memoryService;
        this.localService = localService;
        this.sessionService = sessionService;
        this.storage = PreferencesService.IN_MEMORY_STORAGE;
    }
    PreferencesService.prototype.setStorage = function (storage) {
        if (storage === PreferencesService.IN_MEMORY_STORAGE || storage === PreferencesService.LOCAL_STORAGE || storage === PreferencesService.SESSION_STORAGE) {
            this.storage = storage;
        }
        else {
            console.error('Invalid storage type');
        }
    };
    PreferencesService.prototype.getStorage = function () {
        return this.storage;
    };
    PreferencesService.prototype.usePrefix = function (prefix) {
        if (this.storage === PreferencesService.LOCAL_STORAGE) {
            this.localService.usePrefix(prefix);
        }
        else if (this.storage === PreferencesService.SESSION_STORAGE) {
            this.sessionService.usePrefix(prefix);
        }
        else {
            console.error('You can not set a prefix for In-memory preferences');
        }
    };
    PreferencesService.prototype.clear = function () {
        if (this.storage === PreferencesService.IN_MEMORY_STORAGE) {
            this.memoryService.clear();
        }
        else if (this.storage === PreferencesService.LOCAL_STORAGE) {
            this.localService.clear();
        }
        else {
            this.sessionService.clear();
        }
    };
    PreferencesService.prototype.put = function (key, value) {
        if (this.storage === PreferencesService.IN_MEMORY_STORAGE) {
            this.memoryService.put(key, value);
        }
        else if (this.storage === PreferencesService.LOCAL_STORAGE) {
            this.localService.put(key, value);
        }
        else {
            this.sessionService.put(key, value);
        }
    };
    PreferencesService.prototype.get = function (key) {
        if (this.storage === PreferencesService.IN_MEMORY_STORAGE) {
            return this.memoryService.get(key);
        }
        else if (this.storage === PreferencesService.LOCAL_STORAGE) {
            return this.localService.get(key);
        }
        else {
            return this.sessionService.get(key);
        }
    };
    PreferencesService.prototype.remove = function (key) {
        if (this.storage === PreferencesService.IN_MEMORY_STORAGE) {
            this.memoryService.remove(key);
        }
        else if (this.storage === PreferencesService.LOCAL_STORAGE) {
            this.localService.remove(key);
        }
        else {
            this.sessionService.remove(key);
        }
    };
    PreferencesService.prototype.removeStartsWith = function (startWith) {
        if (this.storage === PreferencesService.IN_MEMORY_STORAGE) {
            this.memoryService.removeStartsWith(startWith);
        }
        else if (this.storage === PreferencesService.LOCAL_STORAGE) {
            this.localService.removeStartsWith(startWith);
        }
        else {
            this.sessionService.removeStartsWith(startWith);
        }
    };
    PreferencesService.prototype.removeEndsWith = function (endsWith) {
        if (this.storage === PreferencesService.IN_MEMORY_STORAGE) {
            this.memoryService.removeEndsWith(endsWith);
        }
        else if (this.storage === PreferencesService.LOCAL_STORAGE) {
            this.localService.removeEndsWith(endsWith);
        }
        else {
            this.sessionService.removeEndsWith(endsWith);
        }
    };
    PreferencesService.prototype.getInCompressFormat = function () {
        if (this.storage === PreferencesService.IN_MEMORY_STORAGE) {
            return this.memoryService.getInCompressFormat();
        }
        else {
            return '';
        }
    };
    PreferencesService.prototype.putFromCompressFormat = function (compressed) {
        if (this.storage === PreferencesService.IN_MEMORY_STORAGE) {
            this.memoryService.putFromCompressFormat(compressed);
        }
    };
    return PreferencesService;
}());
PreferencesService.IN_MEMORY_STORAGE = 1;
PreferencesService.LOCAL_STORAGE = 2;
PreferencesService.SESSION_STORAGE = 3;
PreferencesService.decorators = [
    { type: core_1.Injectable },
];
/** @nocollapse */
PreferencesService.ctorParameters = function () { return [
    { type: memory_storage_service_1.MemoryStorageService, },
    { type: local_storage_service_1.LocalStorageService, },
    { type: session_storage_service_1.SessionStorageService, },
]; };
exports.PreferencesService = PreferencesService;
//# sourceMappingURL=preferences.service.js.map