"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var StorageService = (function () {
    function StorageService(storage) {
        this.storage = storage;
        this.prefix = 'Systelab';
    }
    StorageService.prototype.usePrefix = function (prefix) {
        this.prefix = prefix;
    };
    StorageService.prototype.clear = function () {
        this.storage.clear();
    };
    StorageService.prototype.put = function (key, value) {
        this.storage.setItem(this.prefix + '.' + key, JSON.stringify(value));
    };
    StorageService.prototype.get = function (key) {
        var value = this.parse(this.storage.getItem(this.prefix + '.' + key) || 'null') || null;
        if (value) {
            return value;
        }
        else {
            return undefined;
        }
    };
    StorageService.prototype.remove = function (key) {
        this.storage.removeItem(this.prefix + '.' + key);
    };
    StorageService.prototype.removeStartsWith = function (startWith) {
        for (var i = this.storage.length - 1; i >= 0; i--) {
            var currentKey = this.storage.key(i);
            currentKey = currentKey.slice(this.prefix.length + 1);
            if (currentKey.startsWith(startWith)) {
                this.remove(currentKey);
            }
        }
    };
    StorageService.prototype.removeEndsWith = function (endsWith) {
        for (var i = this.storage.length - 1; i >= 0; i--) {
            var currentKey = this.storage.key(i);
            currentKey = currentKey.slice(this.prefix.length + 1);
            if (currentKey.endsWith(endsWith)) {
                this.remove(currentKey);
            }
        }
    };
    StorageService.prototype.parse = function (text) {
        try {
            return JSON.parse(text) || null;
        }
        catch (e) {
            return text;
        }
    };
    return StorageService;
}());
exports.StorageService = StorageService;
//# sourceMappingURL=storage.service.js.map